@@ -272,6 +272,12 @@ namespace orc {
     return *this;
   }
 
+  SearchArgumentBuilder& SearchArgumentBuilderImpl::maybe() {
+    TreeNode& parent = currTree_.front();
+    parent->addChild(std::make_shared<ExpressionTree>(TruthValue::YES_NO_NULL));
+    return *this;
+  }
+
   /**
    * Recursively explore the tree to find the leaves that are still reachable
    * after optimizations.
