@@ -16,7 +16,6 @@
 package org.apache.orc;
 
 import com.google.common.collect.Lists;
-import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.hive.ql.exec.vector.TimestampColumnVector;
@@ -54,12 +53,11 @@ import static org.junit.jupiter.api.Assertions.assertNull;
 /**
  *
  */
-public class TestOrcTimezonePPD {
+public class TestOrcTimezonePPD implements TestConf {
   private static final Logger LOG = LoggerFactory.getLogger(TestOrcTimezonePPD.class);
 
   Path workDir = new Path(System.getProperty("test.tmp.dir",
     "target" + File.separator + "test" + File.separator + "tmp"));
-  Configuration conf;
   FileSystem fs;
   Path testFilePath;
   static TimeZone defaultTimeZone = TimeZone.getDefault();
@@ -90,7 +88,6 @@ public class TestOrcTimezonePPD {
 
   @BeforeEach
   public void openFileSystem(TestInfo testInfo) throws Exception {
-    conf = new Configuration();
     fs = FileSystem.getLocal(conf);
     testFilePath = new Path(workDir, "TestOrcFile." +
       testInfo.getTestMethod().get().getName() + ".orc");
