@@ -103,6 +103,9 @@ public class Driver {
       System.exit(1);
     }
     Configuration conf = new Configuration();
+    if (Runtime.version().feature() > 21) {
+      conf.setIfUnset("fs.file.impl.disable.cache", "true");
+    }
     Properties confSettings = options.genericOptions.getOptionProperties("D");
     for(Map.Entry pair: confSettings.entrySet()) {
       conf.set(pair.getKey().toString(), pair.getValue().toString());
