@@ -72,7 +72,11 @@ public class RowCount {
   }
 
   public static void main(String[] args) throws Exception {
-    main(new Configuration(), args);
+    Configuration conf = new Configuration();
+    if (Runtime.version().feature() > 21) {
+      conf.setIfUnset("fs.file.impl.disable.cache", "true");
+    }
+    main(conf, args);
   }
 
   private static Options createOptions() {
